#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>

#include "reversigame.h"

class CentralWidget;
QT_BEGIN_NAMESPACE
class QMenu;
class QAction;
QT_END_NAMESPACE

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

private:
    CentralWidget *centralWdgt;
    ReversiGame reversiGame_;

private:
    void createMenuToolbar();

    QMenu *gameMenu;
    QAction *actNewGame;

private slots:
    void slotNewGame();
    void slotGameOver();
    void slotAbout();
    void slotOrientationChanged();

};

#endif // MAINWINDOW_H
